@@ -163,7 +163,11 @@ def _iter_dbapi_cursor(cursor, query, *args, **kwargs):
     cursor.execute(query, *args, **kwargs)
     # fetch one row before iterating, to force population of cursor.description
     # which may be postponed if using server-side cursors
-    it = iter(cursor)
+    # not all database drivers populate cursor after execute so we call fetchall
+    try:
+        it = iter(cursor)
+    except TypeError:
+        it = iter(cursor.fetchall())
     try:
         first_row = next(it)
     except StopIteration:
@@ -179,7 +183,7 @@ def _iter_dbapi_cursor(cursor, query, *args, **kwargs):
 
 
 def _iter_sqlalchemy_engine(engine, query, *args, **kwargs):
-    return _iter_sqlalchemy_connection(engine.contextual_connect(), query,
+    return _iter_sqlalchemy_connection(engine.connect(), query,
                                        *args, **kwargs)
 
 
@@ -537,7 +541,7 @@ def _todb_dbapi_cursor(table, cursor, tablename, schema=None, commit=True,
 def _todb_sqlalchemy_engine(table, engine, tablename, schema=None, commit=True,
                             truncate=False):
 
-    _todb_sqlalchemy_connection(table, engine.contextual_connect(), tablename,
+    _todb_sqlalchemy_connection(table, engine.connect(), tablename,
                                 schema=schema, commit=commit, truncate=truncate)
 
 
